<picture>
    <source media="(prefers-color-scheme: dark)" srcset="doc/source/logo/sober_logo_dark.svg">
    <source media="(prefers-color-scheme: light)" srcset="doc/source/logo/sober_logo_light.svg">
    <img alt="sober logo" src="doc/source/logo/sober_logo_light.svg" width="300">
</picture>

**sober** — **sober** **o**ptimises **b**uilt **e**nvironment **r**obustly 

---

Alpha phase, in development.
